@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #-*- coding: utf-8 -*-
-__all__ = ["utils"]
+__all__ = ["utils", "studentSearch"]
 from cqTools.StudentSearch.utils.login import ReportLogin
 
 class studentSearch(ReportLogin):
